<a id="autonomy.analyse.abci.logs"></a>

# autonomy.analyse.abci.logs

Tools to parse agent logs.

<a id="autonomy.analyse.abci.logs.Color"></a>

## Color Objects

```python
class Color(Enum)
```

Standard terminal color codes.

<a id="autonomy.analyse.abci.logs.parse_file"></a>

#### parse`_`file

```python
def parse_file(filename: str) -> None
```

Parses a log file, e2e or single agent.

